==> multitail-4.0.3.tgz: multitail-4.0.3/globals.c <==
#define _LARGEFILE64_SOURCE     /* required for GLIBC to enable stat64 and friends */
#include <sys/types.h>
#include <regex.h>
#include <sys/stat.h>
#include <unistd.h>

#include "mt.h"

NEWWIN **splitlines = NULL;
NEWWIN *menu_win = NULL;
buffer *lb = NULL;
char *config_file = NULL;
char *mail_spool_file = NULL;
char *nsubwindows = NULL;
char *set_title = NULL;
char *shell = "/bin/sh";
char *tail = "tail";
char *ts_format = "%b %2d %H:%M:%S";
char *statusline_ts_format = "%b %2d %H:%M:%S %Y";
char *cnv_ts_format = "%b %2d %H:%M:%S %Y";
char **color_names = NULL;
char *replace_by_markerline = NULL;
const char *F1 = "For help at any time press F1.";
int *n_win_per_col = NULL;
int *vertical_split = NULL;
color_scheme *cschemes = NULL;
const char *version_str = " --*- multitail " VERSION " (C) 2003-2006 by folkert@vanheusden.com -*--";
conversion *conversions = NULL;
keybinding *keybindings = NULL;
pars_per_file *ppf = NULL;
proginfo *pi = NULL;
check_dir_glob *cdg = NULL;
int n_cdg = 0;

int default_color_scheme = -1;
int max_y, max_x;
int min_n_bufferlines = 25;
int mode_statusline = 1;
int n_children = 0;
int n_conversions = 0;
int n_cschemes = 0;
int n_cschemes;
int n_keybindings = 0;
int n_pars_per_file = 0;
int n_splitlines = 0;
int nfd = 0;
int terminal_index = -1;
int update_interval = 0;
int n_colors_defined = 0;
int check_for_mail = 5;	/* check for mail every 5 seconds */
int default_maxnlines = 0;
int default_maxbytes = 0;
int popup_refresh_interval = 5; /* every 5 seconds */

double heartbeat_interval = 0.0;
double heartbeat_t = 0.0;
off64_t msf_prev_size = 0;

time_t msf_last_check = 0;
time_t mt_started;

pid_t children_list[MAX_N_SPAWNED_PROCESSES];
pid_t tail_proc = 0;	/* process used by checker-proc */
struct stat64 msf_info;
term_t term_type = TERM_IGNORE;
myattr_t markerline_attrs = { -1, -1 };
myattr_t changeline_attrs = { -1, -1 };
myattr_t idleline_attrs   = { -1, -1 };
myattr_t msgline_attrs    = { -1, -1 };
myattr_t statusline_attrs = { -1, -1 };
colorpairs cp;
mode_t def_umask = 0022;

beeb_t beep_method = BEEP_BEEP;
double beep_popup_length = 0.0;

char afs = 0;	/* abbreviate filesize */
char allow_8bit = 0; /* allow 8 bits ascii*/
char banner = 1;
char bright_colors = 0;
char do_refresh = 0;
char filename_only = 0;
char got_sighup = 0;
char mail = 0;
char no_linewrap = 0;
char prev_term_char = -1;
char show_subwindow_id = 0;
char split = 0;
char tab_width = 4;		/* some people use 8 */
char terminal_changed = 0;
char timestamp_in_markerline = 0;
char use_colors = 0;
char warn_closed = 1;
char caret_notation = 0;
char statusline_above_data = 0;
char global_marker_of_other_window = 0;
char markerline_char = '-';
char changeline_char = '-';
char idleline_char   = '-';
char msgline_char   = '-';
char default_bufferwhat = 'f';

==> multitail-5.0.0.tgz: multitail-5.0.0/globals.c <==
#define _LARGEFILE64_SOURCE     /* required for GLIBC to enable stat64 and friends */
#include <sys/types.h>
#include <regex.h>
#include <sys/stat.h>
#include <unistd.h>

#include "mt.h"

NEWWIN **splitlines = NULL;
NEWWIN *menu_win = NULL;
buffer *lb = NULL;
char *config_file = NULL;
char *mail_spool_file = NULL;
char *nsubwindows = NULL;
char *set_title = NULL;
char *shell = "/bin/sh";
char *tail = "tail";
char *ts_format = "%b %d %H:%M:%S";
char *statusline_ts_format = "%b %d %H:%M:%S %Y";
char *cnv_ts_format = "%b %d %H:%M:%S %Y";
char *line_ts_format = "%b %d %H:%M:%S %Y ";
char **color_names = NULL;
char *replace_by_markerline = NULL;
const char *F1 = "For help at any time press F1.";
int *n_win_per_col = NULL;
int *vertical_split = NULL;
color_scheme *cschemes = NULL;
const char *version_str = " --*- multitail " VERSION " (C) 2003-2007 by folkert@vanheusden.com -*--";
conversion *conversions = NULL;
keybinding *keybindings = NULL;
pars_per_file *ppf = NULL;
proginfo *pi = NULL;
check_dir_glob *cdg = NULL;
int n_cdg = 0;
editscheme *pes = NULL;
int n_es = 0;
char *defaultcscheme = NULL;
proginfo *terminal_index = NULL;

int terminal_main_index = -1;
int default_color_scheme = -1;
int max_y, max_x;
int min_n_bufferlines = 25;
int mode_statusline = 1;
int n_children = 0;
int n_conversions = 0;
int n_cschemes = 0;
int n_keybindings = 0;
int n_pars_per_file = 0;
int n_splitlines = 0;
int nfd = 0;
int update_interval = 0;
int n_colors_defined = 0;
int check_for_mail = 5;	/* check for mail every 5 seconds */
int default_maxnlines = 0;
int default_maxbytes = 0;
int popup_refresh_interval = 5; /* every 5 seconds */
int default_line_wrap_offset = 0;
int inverse_attrs = A_REVERSE;
int beep_interval = -1;
int linecounter_for_beep = 0;
int did_n_beeps = 0;
int default_min_shrink = 10;
int wordwrapmaxlength = 10;

double heartbeat_interval = 0.0;
double heartbeat_t = 0.0;
off64_t msf_prev_size = 0;

time_t msf_last_check = 0;
time_t mt_started;

pid_t children_list[MAX_N_SPAWNED_PROCESSES];
pid_t tail_proc = 0;	/* process used by checker-proc */
struct stat64 msf_info;
term_t term_type = TERM_IGNORE;
myattr_t markerline_attrs = { -1, -1 };
myattr_t changeline_attrs = { -1, -1 };
myattr_t idleline_attrs   = { -1, -1 };
myattr_t msgline_attrs    = { -1, -1 };
myattr_t statusline_attrs = { -1, -1 };
myattr_t splitline_attrs  = { -1, -1 };
colorpairs cp;
mode_t def_umask = 0022;
history_t search_h = { NULL, 0, NULL };
history_t cmdfile_h = { NULL, 0, NULL };
mybool_t re_case_insensitive = MY_FALSE;

beeb_t beep_method = BEEP_BEEP;
double beep_popup_length = 0.0;

char afs = 0;	/* abbreviate filesize */
char allow_8bit = 0; /* allow 8 bits ascii*/
char banner = 1;
char bright_colors = 0;
char do_refresh = 0;
char filename_only = 0;
char got_sigusr1 = 0;
char mail = 0;
char no_linewrap = 0;
char prev_term_char = -1;
char show_subwindow_id = 0;
char split = 0;
char tab_width = 4;		/* some people use 8 */
char terminal_changed = 0;
char timestamp_in_markerline = 0;
char use_colors = 0;
char warn_closed = 1;
char caret_notation = 0;
char statusline_above_data = 0;
char global_marker_of_other_window = 0;
char markerline_char = '-';
char changeline_char = '-';
char idleline_char   = '-';
char msgline_char   = '-';
char default_bufferwhat = 'f';
char load_global_config = 1;
char default_linewrap = 'a';
char default_follow_filename = 0;
char do_not_close_closed_windows = 0;
char suppress_empty_lines = 1;
char splitline_mode = SL_REGULAR;
char abort_key = 7;
char exit_key = 3;
char default_sb_showwinnr = 0;

regex_t global_highlight_re;
char *global_highlight_str = NULL;

filterscheme *pfs = NULL;
int n_fs = 0;
